pub enum CreateLoginProfileError {
EntityAlreadyExists(String),
LimitExceeded(String),
NoSuchEntity(String),
PasswordPolicyViolation(String),
ServiceFailure(String),
}Expand description
Errors returned by CreateLoginProfile
Variants
EntityAlreadyExists(String)
The request was rejected because it attempted to create a resource that already exists.
LimitExceeded(String)
The request was rejected because it attempted to create resources beyond the current AWS account limitations. The error message describes the limit exceeded.
NoSuchEntity(String)
The request was rejected because it referenced a resource entity that does not exist. The error message describes the resource.
PasswordPolicyViolation(String)
The request was rejected because the provided password did not meet the requirements imposed by the account password policy.
ServiceFailure(String)
The request processing has failed because of an unknown error, exception or failure.
Implementations
Sourceimpl CreateLoginProfileError
impl CreateLoginProfileError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateLoginProfileError>