pub enum GetOpenIDConnectProviderError {
InvalidInput(String),
NoSuchEntity(String),
ServiceFailure(String),
}Expand description
Errors returned by GetOpenIDConnectProvider
Variants
InvalidInput(String)
The request was rejected because an invalid or out-of-range value was supplied for an input parameter.
NoSuchEntity(String)
The request was rejected because it referenced a resource entity that does not exist. The error message describes the resource.
ServiceFailure(String)
The request processing has failed because of an unknown error, exception or failure.
Implementations