pub enum UpdateAccessKeyError {
LimitExceeded(String),
NoSuchEntity(String),
ServiceFailure(String),
}Expand description
Errors returned by UpdateAccessKey
Variants
LimitExceeded(String)
The request was rejected because it attempted to create resources beyond the current AWS account limits. The error message describes the limit exceeded.
NoSuchEntity(String)
The request was rejected because it referenced a resource entity that does not exist. The error message describes the resource.
ServiceFailure(String)
The request processing has failed because of an unknown error, exception or failure.
Implementations
Sourceimpl UpdateAccessKeyError
impl UpdateAccessKeyError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<UpdateAccessKeyError>